package com.clx.performance.enums;

import com.clx.performance.enums.vehiclewarn.VehicleWarnConfigEnum;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

public class InternalMessageTemplateEnum {

    //运单预警map
    public static Map<Integer,String> CHILD_WARN_MAP = new HashMap<>();
    //线路预警map
    public static Map<Integer,String> LINE_WARN_MAP = new HashMap<>();
    //待报价订单map
    public static Map<Integer,String> WAIT_QUOTATION_ORDER_MAP = new HashMap<>();
    //待审核事项map
    public static Map<Integer,String> WAIT_APPROVED_ITEM_MAP = new HashMap<>();

    //待创建货单map
    public static Map<Integer,String> WAIT_CREATE_ORDER_GOODS_MAP = new HashMap<>();
    //订单通知map
    public static Map<Integer,String> ORDER_NOTICE_MAP = new HashMap<>();
    //投诉通知map
    public static Map<Integer,String> COMPLAINT_NOTICE_MAP = new HashMap<>();
    //司机上报map
    public static Map<Integer,String> DRIVER_REPORT_MAP = new HashMap<>();
    //内部上报map
    public static Map<Integer,String> INTERNAL_REPORT_MAP = new HashMap<>();



    //key:businessType  value: key:具体实际业务类型的code， value:BusinessTypeDetail的code
    public static Map<String, Map<Integer,String>> businessTypeMap = new HashMap<>();
    static {
        CHILD_WARN_MAP.put(VehicleWarnConfigEnum.WarnType.ARRIVE_SEND_DELAY.getCode(),BusinessTypeDetail.ARRIVE_SEND_DELAY.getCode());
        CHILD_WARN_MAP.put(VehicleWarnConfigEnum.WarnType.GOTO_SEND_TIMEOUT.getCode(),BusinessTypeDetail.GOTO_SEND_TIMEOUT.getCode());
        CHILD_WARN_MAP.put(VehicleWarnConfigEnum.WarnType.ARRIVE_RECEIVE_DELAY.getCode(),BusinessTypeDetail.ARRIVE_SEND_DELAY.getCode());
        CHILD_WARN_MAP.put(VehicleWarnConfigEnum.WarnType.GOTO_RECEIVE_TIMEOUT.getCode(),BusinessTypeDetail.ARRIVE_SEND_DELAY.getCode());
        CHILD_WARN_MAP.put(VehicleWarnConfigEnum.WarnType.PARK_TIMEOUT.getCode(),BusinessTypeDetail.ARRIVE_SEND_DELAY.getCode());
        CHILD_WARN_MAP.put(VehicleWarnConfigEnum.WarnType.LOAD_TIMEOUT.getCode(),BusinessTypeDetail.ARRIVE_SEND_DELAY.getCode());
        CHILD_WARN_MAP.put(VehicleWarnConfigEnum.WarnType.UNLOAD_TIMEOUT.getCode(),BusinessTypeDetail.ARRIVE_SEND_DELAY.getCode());






        businessTypeMap.put(BusinessType.CHILD_WARN.getCode(),CHILD_WARN_MAP);
        businessTypeMap.put(BusinessType.LINE_WARN.getCode(),LINE_WARN_MAP);
        businessTypeMap.put(BusinessType.WAIT_QUOTATION_ORDER.getCode(),WAIT_QUOTATION_ORDER_MAP);
        businessTypeMap.put(BusinessType.WAIT_APPROVED_ITEM.getCode(),WAIT_APPROVED_ITEM_MAP);
        businessTypeMap.put(BusinessType.WAIT_CREATE_ORDER_GOODS.getCode(),WAIT_CREATE_ORDER_GOODS_MAP);
        businessTypeMap.put(BusinessType.ORDER_NOTICE.getCode(),ORDER_NOTICE_MAP);
        businessTypeMap.put(BusinessType.COMPLAINT_NOTICE.getCode(),COMPLAINT_NOTICE_MAP);
        businessTypeMap.put(BusinessType.DRIVER_REPORT.getCode(),DRIVER_REPORT_MAP);
        businessTypeMap.put(BusinessType.INTERNAL_REPORT.getCode(),INTERNAL_REPORT_MAP);
    }





    @Getter
    @AllArgsConstructor
    public enum TemplateType {
        ARRIVE_SEND_DELAY(PlatformType.CARRIER, MessageType.WARN, BusinessType.CHILD_WARN,BusinessTypeDetail.ARRIVE_SEND_DELAY),
        GOTO_SEND_TIMEOUT(PlatformType.CARRIER, MessageType.WARN, BusinessType.CHILD_WARN,BusinessTypeDetail.GOTO_SEND_TIMEOUT),
        ARRIVE_RECEIVE_DELAY(PlatformType.CARRIER, MessageType.WARN, BusinessType.CHILD_WARN,BusinessTypeDetail.ARRIVE_RECEIVE_DELAY),
        GOTO_RECEIVE_TIMEOUT(PlatformType.CARRIER, MessageType.WARN, BusinessType.CHILD_WARN,BusinessTypeDetail.GOTO_RECEIVE_TIMEOUT),
        PARK_TIMEOUT(PlatformType.CARRIER, MessageType.WARN, BusinessType.CHILD_WARN,BusinessTypeDetail.PARK_TIMEOUT),
        LOAD_TIMEOUT(PlatformType.CARRIER, MessageType.WARN, BusinessType.CHILD_WARN,BusinessTypeDetail.LOAD_TIMEOUT),
        UNLOAD_TIMEOUT(PlatformType.CARRIER, MessageType.WARN, BusinessType.CHILD_WARN,BusinessTypeDetail.UNLOAD_TIMEOUT),
        ;
        private final PlatformType platform;      //承运平台  司机APP
        private final MessageType messageType;   //预警、待办、通知、上报
        private final BusinessType businessType;   //业务大类   运单预警
        private final BusinessTypeDetail businessDetailType;  //业务详细分类   前往目的地超时等


        public static Optional<TemplateType> getByBusinessTypeDetailCode(String businessTypeDetailCode) {
            return Arrays.stream(values()).filter(e -> e.businessDetailType.code.equals(businessTypeDetailCode)).findFirst();
        }


    }



    @Getter
    @AllArgsConstructor
    public enum BusinessTypeDetail {


        ARRIVE_SEND_DELAY("ARRIVE_SEND_DELAY", "预警通知：到达货源地延误","运单%s,到达货源地延误，请尽快处理。"),
        GOTO_SEND_TIMEOUT("GO_TO_SEND_TIMEOUT", "预警通知：前往货源地超时","运单%s,前往货源地超时，请尽快处理。"),
        ARRIVE_RECEIVE_DELAY("ARRIVE_RECEIVE_DELAY", "预警通知：到达目的地延误","运单%s,到达目的地延误，请尽快处理。"),
        GOTO_RECEIVE_TIMEOUT("GOTO_RECEIVE_TIMEOUT", "预警通知：前往目的地超时","运单%s,到达目的地超时，请尽快处理。"),
        PARK_TIMEOUT("PARK_TIMEOUT", "预警通知：前往货源地超时","运单%s,停留超时，请尽快处理。"),
        LOAD_TIMEOUT("LOAD_TIMEOUT", "预警通知：前往货源地超时","运单%s,装车超时，请尽快处理。"),
        UNLOAD_TIMEOUT("UNLOAD_TIMEOUT", "预警通知：前往货源地超时","运单%s,卸车超时，请尽快处理。"),
        ;

        private final String code;
        private final String title;
        private final String content;


        public static Optional<BusinessTypeDetail> getByCode(String code) {
            return Arrays.stream(values()).filter(e -> e.code.equals(code)).findFirst();
        }
        public static String getTitle(String code) {
            if (code == null) {return null;}
            return getByCode(code).map(BusinessTypeDetail::getTitle).orElse(null);
        }
    }


    @Getter
    @AllArgsConstructor
    public enum BusinessType {
        CHILD_WARN("CHILD_WARN", "运单预警"),
        LINE_WARN("LINE_WARN", "线路预警"),
        WAIT_QUOTATION_ORDER("WAIT_QUOTATION_ORDER", "待报价订单"),
        WAIT_APPROVED_ITEM("WAIT_APPROVED_ITEM", "待审核事项"),
        WAIT_CREATE_ORDER_GOODS("WAIT_CREATE_ORDER_GOODS", "待创建货单"),
        ORDER_NOTICE("ORDER_NOTICE", "订单通知"),
        COMPLAINT_NOTICE("COMPLAINT_NOTICE", "投诉通知"),
        DRIVER_REPORT("DRIVER_REPORT", "司机上报"),
        INTERNAL_REPORT("INTERNAL_REPORT", "内部上报"),

        ;

        private final String code;
        private final String name;
        public static Optional<BusinessType> getByCode(String code) {
            return Arrays.stream(values()).filter(e -> e.code.equals(code)).findFirst();
        }

        public static String getName(String code) {
            if (code == null) {return null;}
            return getByCode(code).map(BusinessType::getName).orElse(null);
        }
    }

    @Getter
    @AllArgsConstructor
    public enum PlatformType {
        CARRIER("carrier-platform-npc", "承运平台"),
        DRIVER_APP("carrier-driver-app", "司机APP"),

        ;

        private final String code;
        private final String name;



        public static Optional<PlatformType> getByCode(String code) {
            return Arrays.stream(values()).filter(e -> e.code.equals(code)).findFirst();
        }

        public static String getName(String code) {
            if (code == null) {return null;}
            return getByCode(code).map(PlatformType::getName).orElse(null);
        }
    }




    //预警、待办、通知、上报
    @Getter
    @AllArgsConstructor
    public enum MessageType {
        WARN("WARN", "预警"),
        WAIT_DEAL("WAIT_DEAL", "待办"),
        NOTICE("NOTICE", "通知"),
        REPORT("REPORT", "上报"),

        ;

        private final String code;
        private final String name;



        public static Optional<MessageType> getByCode(String  code) {
            return Arrays.stream(values()).filter(e -> e.code.equals(code)).findFirst();
        }

        public static String getName(String  code) {
            if (code == null) {return null;}
            return getByCode(code).map(MessageType::getName).orElse(null);
        }
    }











}
